from django.conf import settings
from rest_framework.exceptions import ValidationError
from rest_framework.filters import SearchFilter


class SafeSearchFilter(SearchFilter):
    """
    Django REST Framework's SearchFilter, but with a limit to the amount of words
    that can be simultaneously requested to prevent creating abnormally large SQL requests.
    """

    def get_search_terms(self, request):
        terms = super().get_search_terms(request)
        # Make search terms unique; `a b c b a` becomes `a b c`
        terms = list(set(terms))
        if len(terms) > settings.SEARCH_FILTER_MAX_TERMS:
            raise ValidationError({self.search_param: [
                f"There cannot be more than {settings.SEARCH_FILTER_MAX_TERMS} unique search terms.",
            ]})
        return terms
